@@ -22,7 +22,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/VNOPS/afs_vnop_lookup.c,v 1.1.1.8 2001/07/14 22:19:56 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/afs/VNOPS/afs_vnop_lookup.c,v 1.1.1.9 2001/07/20 10:01:53 hartmans Exp $");
 
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
 #include "../afs/afsincludes.h"	/* Afs-based standard headers */
@@ -1003,8 +1003,8 @@ afs_lookup(adp, aname, avcp, acred)
     tvc = osi_dnlc_lookup (adp, tname, WRITE_LOCK);
     *avcp = tvc;  /* maybe wasn't initialized, but it is now */
     if (tvc) {
-	if (no_read_access && vType(tvc) != VDIR) {
-	    /* need read access on dir to stat non-directory */
+	if (no_read_access && vType(tvc) != VDIR && vType(tvc) != VLNK) {
+	    /* need read access on dir to stat non-directory / non-link */
 	    afs_PutVCache(tvc, WRITE_LOCK);
 	    *avcp = (struct vcache *)0;
 	    code = EACCES;
